'use strict';

const Gettext = imports.gettext;
const {  GObject, St } = imports.gi;
const PopupMenu = imports.ui.popupMenu;

const ExtensionUtils = imports.misc.extensionUtils;
const Me = ExtensionUtils.getCurrentExtension();
const Docker = Me.imports.lib.docker;
const Domain = Gettext.domain(Me.metadata.uuid);
const _ = Domain.gettext;
const ngettext = Domain.ngettext;

var Container_Menu = GObject.registerClass(
	class Container_Menu extends PopupMenu.PopupSubMenuMenuItem {
		_init(container) {
			super._init(container.name);
			this._set_status(container.status);

			switch (container.status){
				case "running":
					this._shell = new PopupMenu.PopupMenuItem(_("Attach Shell"));
					this._shell.connect('activate', () => Docker.run_command(Docker.docker_commands.c_exec, container));
					this.menu.addMenuItem(this._shell);

					this._pause = new PopupMenu.PopupMenuItem(_("Pause"));
					this._pause.connect('activate', () => Docker.run_command(Docker.docker_commands.c_pause, container));
					this.menu.addMenuItem(this._pause);

					this._stop = new PopupMenu.PopupMenuItem(_("Stop"));
					this._stop.connect('activate', () => Docker.run_command(Docker.docker_commands.c_stop, container));
					this.menu.addMenuItem(this._stop);

					this._restart = new PopupMenu.PopupMenuItem(_("Restart"));
					this._restart.connect('activate', () => Docker.run_command(Docker.docker_commands.c_restart, container));
					this.menu.addMenuItem(this._restart);
				break;

				case "paused":
					this._unpause = new PopupMenu.PopupMenuItem(_("Unpause"));
					this._unpause.connect('activate', () => Docker.run_command(Docker.docker_commands.c_unpause, container));
					this.menu.addMenuItem(this._unpause);

					this._stop = new PopupMenu.PopupMenuItem(_("Stop"));
					this._stop.connect('activate', () => Docker.run_command(Docker.docker_commands.c_stop, container));
					this.menu.addMenuItem(this._stop);

					this._restart = new PopupMenu.PopupMenuItem(_("Restart"));
					this._restart.connect('activate', () => Docker.run_command(Docker.docker_commands.c_restart, container));
					this.menu.addMenuItem(this._restart);
				break;

				default:
					this._start = new PopupMenu.PopupMenuItem(_("Start"));
					this._start.connect('activate', () => Docker.run_command(Docker.docker_commands.c_start, container));
					this.menu.addMenuItem(this._start);

					this._start_i = new PopupMenu.PopupMenuItem(_("Start interactive"));
					this._start_i.connect('activate', () => Docker.run_command(Docker.docker_commands.c_start_i, container));
					this.menu.addMenuItem(this._start_i);
			}


			this._remove = new PopupMenu.PopupMenuItem(_("Remove"));
			this._remove.connect('activate', () => Docker.run_command(Docker.docker_commands.c_rm, container));
			this.menu.addMenuItem(this._remove);
		}

		_set_status(status) {
			this._icon = new St.Icon({
				icon_name: 'media-record-symbolic',
				style_class: 'stop',
				icon_size: '14'
			});

			if (status == "running") {
				this._icon.style_class = 'running';
			}

			this.actor.insert_child_at_index(this._icon, 1);
		}
	}
)